package net.ugen.rnplugin.nativaPlugin;

import android.app.AppOpsManager;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothManager;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.location.LocationManager;
import android.net.ConnectivityManager;
import android.net.Network;
import android.net.NetworkInfo;
import android.net.Uri;
import android.os.Build;
import android.provider.Settings;
import android.support.annotation.RequiresApi;
import android.support.v4.app.NotificationManagerCompat;
import android.widget.Toast;
import com.facebook.infer.annotation.SuppressLint;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.WritableArray;


import net.ugen.rnplugin.nativaPlugin.Help.AppPageHelper;
import net.ugen.rnplugin.nativaPlugin.Help.NotificationPageHelper;

import java.lang.reflect.Array;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by hatsuhodohodo on 2018/6/27.
 */

public class NativePlugin extends ReactContextBaseJavaModule {

    private static final String CHECK_OP_NO_THROW = "checkOpNoThrow";
    private static final String OP_POST_NOTIFICATION = "OP_POST_NOTIFICATION";
    private static final String LOCATION = "LOCATION";
    private static final String BLE = "BLE";
    private ReactContext mReactContext;

    public NativePlugin(ReactApplicationContext reactContext) {
        super(reactContext);
        mReactContext = reactContext;
    }
    //网络是否打开
    @ReactMethod
    public void isNetWorkingOpen(final Promise promise) {
        if (this.checkState_23orNew()){
            promise.resolve("有网");
        }else {
            promise.resolve("没网");
        }
    }
    //通知是否打开
    @ReactMethod
    public void isNotifycationOpen(String arg,final Promise promise){
        NotificationManagerCompat notificationManagerCompat = NotificationManagerCompat.from(mReactContext);

        boolean isOpen = notificationManagerCompat.areNotificationsEnabled();
        if (isOpen){
            promise.resolve("通知：打开");
        }else {
            promise.resolve("通知：关闭");
        }
    }
    
    @ReactMethod
    public void openAppSetting(final Promise promise){
//        this.requestPermission(Settings.ACTION_SETTINGS);

        promise.resolve(this.toSetting("app"));
    }
    public boolean toSetting(String type){
        Context context = mReactContext;
        switch(type.toLowerCase()){
            case "notify":
                NotificationPageHelper.open(context);
                break;
            case "app":
                AppPageHelper.open(context);
                break;
            default:
                return true;
        }
        return true;
    }
    @ReactMethod
    public void openWifiSetting(final Promise promise){
        this.requestPermission(Settings.ACTION_AIRPLANE_MODE_SETTINGS);
        promise.resolve(true);
    }
    @RequiresApi(api = Build.VERSION_CODES.JELLY_BEAN_MR2)
    @ReactMethod
    public void openBluetoothSetting(final Promise promise){
        if (this.checkHasBluetooth(mReactContext)){
            Intent enableIntent = new Intent(Settings.ACTION_BLUETOOTH_SETTINGS);
            if (enableIntent == null){
                Toast.makeText(mReactContext,"没有蓝牙功能",2);
                return;
            }
            Toast.makeText(mReactContext,"蓝牙功能",2);
            mReactContext.startActivity(enableIntent);
            promise.resolve(true);
        }else {
            Toast.makeText(mReactContext,"没有蓝牙功能",2);
            promise.reject("500","没有蓝牙功能");
        }
    }
    
    @RequiresApi(api = Build.VERSION_CODES.JELLY_BEAN_MR2)
    public boolean checkHasBluetooth(Context context){
        final BluetoothManager bluetoothManager =
        (BluetoothManager) context.getSystemService(Context.BLUETOOTH_SERVICE);
        
        if (bluetoothManager == null){
            return false;
        }
        if (bluetoothManager.getAdapter() == null){
            return false;
        }
        return true;
    }
    
    @android.annotation.SuppressLint("WrongConstant")
    protected void requestPermission(String arg) {
        
        if (mReactContext == null){
            return;
        }
        Intent intent = new Intent(arg);
        if (intent == null){
            
            return;
        }
        mReactContext.startActivity(intent);
    }
    @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
    public boolean checkState_23orNew(){
        //获得ConnectivityManager对象
        ConnectivityManager connMgr = (ConnectivityManager) mReactContext.getSystemService(Context.CONNECTIVITY_SERVICE);
        
        //获取所有网络连接的信息
        Network[] networks = connMgr.getAllNetworks();
        //用于存放网络连接信息
        StringBuilder sb = new StringBuilder();
        //通过循环将网络信息逐个取出来
        for (int i=0; i < networks.length; i++){
            //获取ConnectivityManager对象对应的NetworkInfo对象
            NetworkInfo networkInfo = connMgr.getNetworkInfo(networks[i]);
            
            return networkInfo.isConnected();
        }
        return false;
    }
    @Override
    public String getName() {
        return "NativePluginReactPackage";
    }
}
